@@ -1,4 +1,24 @@
+=head1 NAME
 
+PDL::Core::Dev - PDL development module
+
+=head1 DESCRIPTION
+
+This module encapsulates most of the stuff useful for
+PDL development and is often used from within Makefile.PL's.
+
+=head1 SYNOPSIS
+
+   use PDL::Core::Dev;
+   if ($^O =~ /win32/i) {
+    warn "Win32 systems not yet supported. Will not build PDL::IO::Browser";
+    write_dummy_make(unsupported('PDL::XXX','win32'));
+    return;
+   }
+
+=head1 FUNCTIONS
+
+=cut   
 
 # Stuff used in development/install environment of PDL Makefile.PL's
 # - not part of PDL itself.
@@ -9,11 +29,12 @@ use English; use Exporter; use DynaLoader;
 use IO::File;
 @ISA    = qw( Exporter DynaLoader );
 
-@EXPORT = qw(genpp %PDL_DATATYPES PDL_INCLUDE PDL_TYPEMAP
+@EXPORT = qw( isbigendian genpp %PDL_DATATYPES 
+	     PDL_INCLUDE PDL_TYPEMAP
 		 PDL_INST_INCLUDE PDL_INST_TYPEMAP
 		 pdlpp_postamble_int pdlpp_stdargs_int
 		 pdlpp_postamble pdlpp_stdargs write_dummy_make
-                unsupported getcyglib
+                unsupported getcyglib trylink
 		 );
 
 # Installation locations
@@ -51,8 +72,8 @@ my $libs = defined $::PDL_CONFIG{MALLOCDBG}->{libs} ?
 
 %PDL_DATATYPES = ();
 foreach $key (keys %PDL::Types::typehash) {
-  $PDL_DATATYPES{$PDL::Types::typehash{$key}->{'sym'}} =
-    $PDL::Types::typehash{$key}->{'ctype'};
+    $PDL_DATATYPES{$PDL::Types::typehash{$key}->{'sym'}} =
+	$PDL::Types::typehash{$key}->{'ctype'};
 }
 
 # non-blocking IO configuration
@@ -60,6 +81,37 @@ foreach $key (keys %PDL::Types::typehash) {
 $O_NONBLOCK = defined $Config{'o_nonblock'} ? $Config{'o_nonblock'}
                 : 'O_NONBLOCK';
 
+=head2 isbigendian
+
+=for ref
+
+Is the machine big or little endian?
+
+=for example
+
+  print "Your machins is big endian.\n" if isbigendian();
+
+returns 1 if the machine is big endian, 0 if little endian,
+or dies if neither.  It uses the C<byteorder> element of
+perl's C<%Config> array.
+
+=for usage
+
+   my $retval = isbigendian();
+
+=cut
+
+# big/little endian?
+sub isbigendian {
+    use Config;
+    my $byteorder = $Config{byteorder} || 
+	die "ERROR: Unable to find 'byteorder' in perl's Config\n";
+    return 1 if $byteorder eq "4321";
+    return 1 if $byteorder eq "87654321";
+    return 0 if $byteorder eq "1234";
+    return 0 if $byteorder eq "12345678";
+    die "ERROR: PDL does not understand your machine's byteorder ($byteorder)\n"; 
+}
 
 #################### PDL Generic PreProcessor ####################
 #
@@ -266,13 +318,15 @@ sub whereami_inst {
 
 # This is the function internal for PDL.
 # Later on, we shall provide another for use outside PDL.
+#
+# added badsupport.p as a requisite
 sub pdlpp_postamble_int {
 	join '',map { my($src,$pref,$mod) = @$_;
 	my $w = whereami_any();
 	$w =~ s%/((PDL)|(Basic))$%%;  # remove the trailing subdir
 qq|
 
-$pref.pm: $src $w/Basic/Gen/pm_to_blib
+$pref.pm: $src $w/Basic/Gen/pm_to_blib $w/Basic/Core/badsupport.p
 	\$(PERL) -I$w/blib/lib -I$w/blib/arch \"-MPDL::PP qw/$mod $mod $pref/\" $src
 
 $pref.xs: $pref.pm
@@ -311,6 +365,10 @@ sub pdlpp_stdargs_int {
  my($rec) = @_;
  my($src,$pref,$mod) = @$rec;
  my $w = whereami();
+ my $malloclib = exists $PDL_CONFIG{MALLOCDBG}->{libs} ?
+   $PDL_CONFIG{MALLOCDBG}->{libs} : '';
+ my $mallocinc = exists $PDL_CONFIG{MALLOCDBG}->{include} ?
+   $PDL_CONFIG{MALLOCDBG}->{include} : '';
  return (
  	%::PDL_OPTIONS,
 	 'NAME'  	=> $mod,
@@ -319,8 +377,8 @@ sub pdlpp_stdargs_int {
 	 'OBJECT'       => "$pref\$(OBJ_EXT)",
 	 PM 	=> {"$pref.pm" => "\$(INST_LIBDIR)/$pref.pm"},
 	 MAN3PODS => {"$pref.pm" => "\$(INST_MAN3DIR)/$mod.\$(MAN3EXT)"},
-	 'INC'          => &PDL_INCLUDE()." $inc",
-	 'LIBS'         => ["$libs "],
+	 'INC'          => &PDL_INCLUDE()." $inc $mallocinc",
+	 'LIBS'         => ["$libs $malloclib "],
 	 'clean'        => {'FILES'  => "$pref.xs $pref.pm $pref\$(OBJ_EXT) $pref.c"},
  );
 }
@@ -378,7 +436,142 @@ $lp =~ s|^([a-z,A-Z]):|//$1|g;
 return "-L$lp -l$lib";
 }
 
+=head2 trylink
+
+=for ref
+
+a perl configure clone
+
+=for example
+
+  if (trylink 'libGL', '', 'char glBegin(); glBegin();', '-lGL') {
+    $libs = '-lGLU -lGL';
+    $have_GL = 1;
+  } else {
+    $have_GL = 0;
+  }
+  $maybe = 
+    trylink 'libwhatever', $inc, $body, $libs, {MakeMaker=>1, Hide=>0};
+
+Try to link some C-code making up the body of a function
+with a given set of library specifiers
+
+return 1 if successful, 0 otherwise
+
+=for usage
+
+   trylink $infomsg, $include, $progbody, $libs [,{OPTIONS}];
+
+Takes 4 + 1 optional argument.
+
+=over 5
+
+=item *
+
+an informational message to print (can be empty)
+
+=item *
+
+any commands to be included at the top of the generated C program
+(typically something like C<#include "mylib.h">)
+
+=item *
+
+the body of the program (in function main)
+
+=item *
+
+library flags to use for linking. Preprocessing
+by MakeMaker should be performed as needed (see options and example).
+
+=item OPTIONS
+
+=over
+
+=item 2
+
+=item MakeMaker
+
+Preprocess library in the way MakeMaker does things. This is
+advisable to ensure that your code will actually work after the link
+specs have been processed by MakeMaker.
+
+=item Hide
+
+Controls of linking output etc is hidden from the user or not.
+On by default.
+
+=back
+
+=back
+
+=cut
+
+
+sub trylink {
+  my $opt = ref $_[$#_] eq 'HASH' ? pop : {};
+  my ($txt,$inc,$body,$libs) = @_;
+
+  require File::Spec;
+  my $fs = 'File::Spec';
+  sub cdir { return $fs->catdir(@_)}
+  sub cfile { return $fs->catfile(@_)}
+  use Config;
+
+  # check if MakeMaker should be used to preprocess the libs
+  my $mmprocess = exists $opt->{MakeMaker} && $opt->{MakeMaker};
+  my $hide = exists $opt->{Hide} ? $opt->{Hide} : 1;
+
+  if ($mmprocess) {
+      require ExtUtils::MakeMaker;
+      require ExtUtils::Liblist;
+      my $self = new ExtUtils::MakeMaker {DIR =>  [],'NAME' => 'NONE'};
+
+      # ExtUtils::Liblist seems to have changed in perl5.6.1, although
+      # its documentation has not
+      my @libs;
+      if ( $] >= 5.006001 ) {
+	  @libs = ExtUtils::Liblist::Kid::ext($self, $libs, 0);
+      } else {
+	  @libs = ExtUtils::Liblist::ext($self, $libs, 0);
+      }
+
+      print "processed LIBS: $libs[0]\n" unless $hide;
+      $libs = $libs[0]; # replace by preprocessed libs
+  }
+
+  print "     Trying $txt...\n     " unless $txt =~ /^\s*$/;
+
+  my $HIDE = ($^O =~ /MSWin/) || !$hide ? '' : '>/dev/null 2>&1'; 
+  my $td = $^O =~ /MSWin/ ? 'TEMP' : 'tmp';
+  my $tempd = defined $ENV{TEMP} ? $ENV{TEMP} :
+            defined $ENV{TMP} ? $ENV{TMP} :
+                           cdir($fs->rootdir,$td);
+
+  my ($tc,$te) = map {cfile($tempd,"testfile$_")} ('.c','');
+  open FILE,">$tc" or die "couldn't open testfile for writing";
+  my $prog = <<"EOF";
+$inc
+
+int main(void) {
+$body
+
+return 0;
+
+}
+
+EOF
+
+  print FILE $prog;
+  close FILE;
+  # print "test prog:\n$prog\n";
+  print "$Config{cc} -o $te $tc $libs $HIDE ...\n" unless $hide;
+  my $success = (system("$Config{cc} -o $te $tc $libs $HIDE") == 0) && 
+    -e $te ? 1 : 0;
+  unlink "$te","$tc";
+  print $success ? "\t\tYES\n" : "\t\tNO\n" unless $txt =~ /^\s*$/;
+  return $success;
+}
+
 1; # Return OK
 
-
-
