@@ -17,16 +17,19 @@ if start-up time becomes an issue.
    use PDL::Core;
    use PDL::Ops;
    use PDL::Primitive;
+   use PDL::Ufunc;
    use PDL::Basic;
    use PDL::Slices;
+   use PDL::Bad;
    use PDL::Version;
    use PDL::IO::Misc;
+   use PDL::Lvalue;
 
 =cut
 
 
 # set the version: 
-$PDL::VERSION = '2.1.1';
+$PDL::VERSION = '2.2.1'; # delete 'cvs' bit for release !
 
 # Main loader of standard PDL package
 
@@ -42,8 +45,11 @@ package $pkg;
 use PDL::Core;
 use PDL::Ops;
 use PDL::Primitive;
+use PDL::Ufunc;
 use PDL::Basic;
 use PDL::Slices;
+use PDL::Bad;
+use PDL::Lvalue;
 
 # Load these for TPJ compatibility
 
