@@ -220,13 +220,18 @@ sub _mk_mat {
 	$this->{Weights} = $tdw;
 }
 
+sub chkdefault ($$) {
+  my ($var,$def);
+  return $def if !ref $var && $var == 0;
+  return defined $var ? $var : $def;
+}
+
 sub new ($$) {
 	my($type,$pars) = @_;
 	my $this = bless {},$type;
-# None of the following can be zero so we can use or.
-	$this->{NLags} = ((delete $pars->{NLags}) or 2);
-	$this->{LagInterval} = ((delete $pars->{LagInterval}) or 1);
-	$this->{LagsBehind} = ((delete $pars->{LagsBehind}) or 1);
+	$this->{NLags} = chkdefault(delete $pars->{NLags}, 2);
+	$this->{LagInterval} = chkdefault(delete $pars->{LagInterval}, 1);
+	$this->{LagsBehind} = chkdefault(delete $pars->{LagsBehind}, 1);
 	$this->{Smooth} = (delete $pars->{Smooth});
 
 	$this->{NDeleted} = $this->{LagInterval} * ($this->{NLags} +
@@ -234,7 +239,7 @@ sub new ($$) {
 	$this->{NTotLags} = $this->_ntotlags();
 	(my $data = delete $pars->{Data}) ;
 	my ($auc,$auc1);
-	if($data) {
+	if(defined $data) {
 		my $atmp;
 		my $n = $this->{NTotLags};
 		my $da = avg($data);
@@ -246,7 +251,7 @@ sub new ($$) {
 		$auc /= $ldata->getdim(0) * $data->getdim(1);
 		$auc -= $da ** 2;
 #		print "AUC: $auc\n";
-	} elsif(($auc1 = delete $pars->{AutoCovar})) {
+	} elsif(defined ($auc1 = delete $pars->{AutoCovar})) {
 		if($this->{LagInterval} != 1) {
 			$auc = $auc1->slice("0:$this->{LagInterval}:-1");
 		} else {
